Enum Call

pub enum Call<T: Config> {
    create_pool {
        staked_asset_id: Box<T::AssetId>,
        reward_asset_id: Box<T::AssetId>,
        reward_rate_per_block: T::Balance,
        expiry: DispatchTime<BlockNumberFor<T>>,
        admin: Option<T::AccountId>,
    },
    stake {
        pool_id: PoolId,
        amount: T::Balance,
    },
    unstake {
        pool_id: PoolId,
        amount: T::Balance,
        staker: Option<T::AccountId>,
    },
    harvest_rewards {
        pool_id: PoolId,
        staker: Option<T::AccountId>,
    },
    set_pool_reward_rate_per_block {
        pool_id: PoolId,
        new_reward_rate_per_block: T::Balance,
    },
    set_pool_admin {
        pool_id: PoolId,
        new_admin: T::AccountId,
    },
    set_pool_expiry_block {
        pool_id: PoolId,
        new_expiry: DispatchTime<BlockNumberFor<T>>,
    },
    deposit_reward_tokens {
        pool_id: PoolId,
        amount: T::Balance,
    },
    cleanup_pool {
        pool_id: PoolId,
    },
    // some variants omitted
}
Pallet’s callable functions.

Variants



create_pool

Create a new reward pool.

Parameters:

  • origin: must be Config::CreatePoolOrigin;
  • staked_asset_id: the asset to be staked in the pool;
  • reward_asset_id: the asset to be distributed as rewards;
  • reward_rate_per_block: the amount of reward tokens distributed per block;
  • expiry: the block number at which the pool will cease to accumulate rewards. The DispatchTime::After variant evaluated at the execution time.
  • admin: the account allowed to extend the pool expiration, increase the rewards rate and receive the unutilized reward tokens back after the pool completion. If None, the caller is set as an admin.

Fields

staked_asset_id: Box<T::AssetId>
reward_asset_id: Box<T::AssetId>
reward_rate_per_block: T::Balance
admin: Option<T::AccountId>


stake

Stake additional tokens in a pool.

A freeze is placed on the staked tokens.

Fields

pool_id: PoolId
amount: T::Balance


unstake

Unstake tokens from a pool.

Removes the freeze on the staked tokens.

Parameters:

  • origin: must be the staker if the pool is still active. Otherwise, any account.
  • pool_id: the pool to unstake from.
  • amount: the amount of tokens to unstake.
  • staker: the account to unstake from. If None, the caller is used.

Fields

pool_id: PoolId
amount: T::Balance
staker: Option<T::AccountId>


harvest_rewards

Harvest unclaimed pool rewards.

Parameters:

  • origin: must be the staker if the pool is still active. Otherwise, any account.
  • pool_id: the pool to harvest from.
  • staker: the account for which to harvest rewards. If None, the caller is used.

Fields

pool_id: PoolId
staker: Option<T::AccountId>


set_pool_reward_rate_per_block

Modify a pool reward rate.

Currently the reward rate can only be increased.

Only the pool admin may perform this operation.

Fields

pool_id: PoolId
new_reward_rate_per_block: T::Balance


set_pool_admin

Modify a pool admin.

Only the pool admin may perform this operation.

Fields

pool_id: PoolId
new_admin: T::AccountId


set_pool_expiry_block

Set when the pool should expire.

Currently the expiry block can only be extended.

Only the pool admin may perform this operation.

Fields

pool_id: PoolId


deposit_reward_tokens

Convenience method to deposit reward tokens into a pool.

This method is not strictly necessary (tokens could be transferred directly to the pool pot address), but is provided for convenience so manual derivation of the account id is not required.

Fields

pool_id: PoolId
amount: T::Balance


cleanup_pool

Cleanup a pool.

Origin must be the pool admin.

Cleanup storage, release any associated storage cost and return the remaining reward tokens to the admin.

Fields

pool_id: PoolId

Implementations

Source

impl<T: Config> Call<T>

pub fn new_call_variant_create_pool( staked_asset_id: Box<T::AssetId>, reward_asset_id: Box<T::AssetId>, reward_rate_per_block: T::Balance, expiry: DispatchTime<BlockNumberFor<T>>, admin: Option<T::AccountId>, ) -> Self

Create a call with the variant create_pool.

pub fn new_call_variant_stake(pool_id: PoolId, amount: T::Balance) -> Self

Create a call with the variant stake.

pub fn new_call_variant_unstake( pool_id: PoolId, amount: T::Balance, staker: Option<T::AccountId>, ) -> Self

Create a call with the variant unstake.

pub fn new_call_variant_harvest_rewards( pool_id: PoolId, staker: Option<T::AccountId>, ) -> Self

Create a call with the variant harvest_rewards.

pub fn new_call_variant_set_pool_reward_rate_per_block( pool_id: PoolId, new_reward_rate_per_block: T::Balance, ) -> Self

Create a call with the variant set_pool_reward_rate_per_block.

pub fn new_call_variant_set_pool_admin( pool_id: PoolId, new_admin: T::AccountId, ) -> Self

Create a call with the variant set_pool_admin.

pub fn new_call_variant_set_pool_expiry_block( pool_id: PoolId, new_expiry: DispatchTime<BlockNumberFor<T>>, ) -> Self

Create a call with the variant set_pool_expiry_block.

pub fn new_call_variant_deposit_reward_tokens( pool_id: PoolId, amount: T::Balance, ) -> Self

Create a call with the variant deposit_reward_tokens.

pub fn new_call_variant_cleanup_pool(pool_id: PoolId) -> Self

Create a call with the variant cleanup_pool.